<?php
/**
 * @file
 * Administrative page callbacks for the Mobile Switch module.
 */

function mobile_switch_settings_form() {
  $module_path = drupal_get_path('module', 'mobile_switch');
  drupal_add_js($module_path . '/js/mobile_switch.admin.js', array('scope' => 'footer'));
  drupal_add_css($module_path . '/css/mobile_switch.admin.css');

  $form = array();
  $active_themes = array_merge(array('none' => t('Do not use')), mobile_switch_get_themes());

  $form['global_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Mobile Switch settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE
  );
  $form['global_settings']['mobile_switch_mobile_theme'] = array(
    '#type' => 'select',
    '#title' => t('Mobile theme'),
    '#description' => t('Which theme should be used as default theme when a mobile device detected.'),
    '#options' => $active_themes,
    '#default_value' => variable_get('mobile_switch_mobile_theme', 'none')
  );
  // Development.
  $form['development'] = array(
    '#type' => 'fieldset',
    '#title' => t('Development'),
    '#description' => t('Mobile Switch can help to develop a mobile site.'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('mobile_switch_developer', 0) || variable_get('mobile_switch_deskbrowser', 0)) ? FALSE : TRUE,
    '#states' => array(
      'invisible' => array(
        ':input[name="mobile_switch_mobile_theme"]' => array('value' => 'none')
      )
    )
  );
  $form['development']['mobile_switch_developer'] = array(
    '#type' => 'select',
    '#title' => t('Developer modus'),
    '#description' => t('Extends the browser detection for desktop emulators such as <em>Opera mobile</em>, <em>Fennec</em> or more other. Don\'t use it on production sites.'),
    '#options' => array(
      FALSE => t('No'),
      TRUE => t('Yes')
    ),
    '#default_value' => variable_get('mobile_switch_developer', 0)
  );
  $form['development']['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced developer modus settings'),
    '#collapsible' => TRUE,
    '#collapsed' => variable_get('mobile_switch_display_useragent', 0) ? FALSE : TRUE,
    '#states' => array(
      'visible' => array(
        ':input[name="mobile_switch_developer"]' => array('value' => '1')
      )
    )
  );
  $form['development']['advanced']['mobile_switch_emulator_strings'] = array(
    '#type' => 'textarea',
    '#title' => t('Mobile emulator identification'),
    '#description' => "Configure user agent string parts. Use ONLY letters - no other characters! DO NOT use the '*' wildcard character! Enter one string per line. As example the default string parts: <pre>Fennec\nAndroid\nTablet\nMobi</pre> The string detection is case insensitive.",
    '#default_value' => variable_get('mobile_switch_emulator_strings', "Fennec\nAndroid\nTablet\nMobi"),
    '#required' => TRUE,
    '#element_validate' => array('_mobile_switch_emulator_strings_validate')
  );
  $form['development']['advanced']['mobile_switch_display_useragent'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display user agent'),
    '#description' => t('Use this function to display a message that contains a user agent string. Do not forget to turn off this option. For the display is required: the permissions %administer-site-configuration or %administer-themes.', array('%administer-site-configuration' => t('Administer site configuration'), '%administer-themes' => t('Administer themes'))),
    '#default_value' => variable_get('mobile_switch_display_useragent', 0)
  );
  $form['development']['mobile_switch_deskbrowser'] = array(
    '#type' => 'select',
    '#title' => t('Desktop browser'),
    '#description' => t('Use the %mobile-theme with desktop browsers. Do not forget to turn off this option on production sites.', array('%mobile-theme' => t('Mobile theme'))),
    '#options' => array(
      TRUE => t('Yes'),
      FALSE => t('No')
    ),
    '#default_value' => variable_get('mobile_switch_deskbrowser', 0)
  );

  $form['#submit'][] = 'mobile_switch_settings_form_submit';

  return system_settings_form($form);
}

/**
 * Form submission handler for mobile_switch_settings_form().
 *
 * @see mobile_switch_settings_form()
 */
function mobile_switch_settings_form_submit($form, &$form_state) {
  // It exist problems if used a "mobile jQuery" based theme as mobile theme.
  // This problems cannot be solved here.
  drupal_flush_all_caches();
  drupal_set_message(t('Caches cleared.'), 'status');
}

/**
 * Render API callback: Validates the user agent string parts.
 *
 * Ensures that only letters and no blank lines has been entered.
 *
 * This function is assigned as an #element_validate callback in
 * mobile_switch_settings_form().
 */
function _mobile_switch_emulator_strings_validate($element, &$form_state) {
  if (preg_match("/[^a-z][^\na-z]|[a-z][^\na-z]$|.{0}\n$/i", $element['#value'])) {
    form_error($element, t('%title: Possible only letters and no blank lines.', array('%title' => t($element['#title']))));
  }
}
